#!/usr/bin/perl
use 5.010;
use strict;
use warnings;

use YAML::CacheLoader qw(LoadFile);

my $input_yml       = shift or die "YAML file needed as input param";
my $underlyings = LoadFile($input_yml);

for my $ul (keys %$underlyings) {
    say $ul;
}

