#!/usr/bin/perl
use strict; use warnings;

use lib 'lib';
use Test::More;
use Test::Exception;
use Finance::Asset;

lives_ok { my $asset = Finance::Asset->new('frxAUDUSD') } 'YAML loaded';

done_testing();

